<template>
    <order-detail-layout :cart_data="cart_data" :loading="loading">
        <template v-slot:order_detail_block>
                <order-list :cart_data="cart_data" @get-cart="getCart" @update-qty="updateQty"></order-list>
            </template>
            <template v-slot:order_total_block>
                <order-total :cart_data="cart_data"></order-total>
            </template>
    </order-detail-layout>
</template>
<script>
import {cloneDeep} from 'lodash';
import OrderList from '~/components/front-end/cart-component/order-list.vue';
import OrderTotal from '~/components/front-end/cart-component/order-total.vue';
import OrderDetailLayout from '~/layouts/cart/order-detail.vue';
export default {
    components:{OrderDetailLayout: ()=>import('~/layouts/cart/order-detail.vue'), OrderList: ()=>import('~/components/front-end/cart-component/order-list.vue'), OrderTotal : ()=>import('~/components/front-end/cart-component/order-total.vue')},
    data() {
        return {
            cart_data   : cloneDeep(this.$store.state.front_end_data.cart_data),
            loading   : false,
            insert_code : false,
            domain      : this.$store.state.front_end_data.domain, 
        }
    },
    head() {
        return {
            title: `Order Summary - ${this.domain.name}`,
            script : [
              {
                src: '/front-end/js/google-analytics.js'
              }
            ],
            meta: [
                {
                  hid: 'description',
                  name: 'description',
                  content: "Cart"
                },
                {
                  hid: 'og:title',
                  name: 'og:title',
                  content: "Cart"
                },
                {
                  hid: 'og:description',
                  name: 'og:description',
                  content: "Cart"
                },{
                  hid: 'og:type',
                  name: 'og:type',
                  content: "Website"
                },
                {
                  hid: 'og:url',
                  name: 'og:url',
                  content: this.domain.url + this.$route.fullPath
                },
                {
                  hid: 'og:url',
                  name: 'og:site_name',
                  content: this.domain.name
                },
                {
                  hid: 'og:image',
                  name: 'og:image',
                  content: "/images/logo.png"
                },
                {
                  hid: 'name',
                  name: 'twitter:card',
                  content: "summary_large_image"
                },
                {
                  hid: 'name',
                  name: 'twitter:title',
                  content: "Cart"
                },
                {
                  hid: 'name',
                  name: 'twitter:description',
                  content: "Cart"
                },
                {
                  hid: 'name',
                  name: 'twitter:image:src',
                  content: "/images/logo.png"
                },
                {
                  hid: 'name',
                  name: 'twitter:site',
                  content: this.domain.name
                },
              ],
          }
    },
    mounted() {
        this.updateQty();
        if((this.cart_data!=null && this.cart_data!='') &&(!this.insert_code)) {
            let cart_data = [];
            this.cart_data.cart_details.forEach((a,i)=>{
                let push_data = {
                    item_name       : a.product.name,
                    item_id         : a.product.id,
                    price           : a.product_price,
                    quantity        : a.qty,
                    variant_id      : a.selected_price_type,
                    item_category   : (a.product.default_category!=null) ? a.product.default_category.name : ""
                };
                cart_data.push(push_data);
            });
            productSelection(cart_data,'view_cart');
            this.insert_code = true;
        }
    },
    methods : {
        getCart() {
            this.loading= true;
            let data = {
                cart_id     : this.$auth.$storage.getUniversal('cart_id'),
                domain_id   : this.$store.state.front_end_data.domain_id,
                location    : (this.$auth.$storage.getUniversal('location')!=undefined) ? this.$auth.$storage.getUniversal('location') : null
            };
            this.$axios.$post(`/api/get-cart`,data)
            .then(resp=>{
                this.cart_data = resp;
                this.updateQty();
                this.loading= false;
            });
        },
        updatePrice() {
            let pickup_available = this.cart_data.cart_details.filter(x=> (!x.pickup));
            let shipping_charge  = 0;
            pickup_available.forEach((a,i)=>{
              if(a.cartage_available) {
                let cartage = a.product.default_category.cartage;
                if(Boolean(a.product.cartage_override)) {
                  cartage = a.product.cartage;
                }
                shipping_charge = Number(shipping_charge) + Number(cartage);
              }
            });
            this.cart_data.shipping_charge = shipping_charge;
            this.cart_data.total_amount = Number(this.cart_data.refundable_amount)+Number(this.cart_data.shipping_charge)+Number(this.cart_data.admin_fee)
        },
        updateQty() {
            this.updatePrice();
            this.cart_data.cart_details = this.cart_data.cart_details.map((x)=>({...x,total : (x.qty*x.product_price)}));
            let total_amount  = 0;
            this.cart_data.cart_details.forEach((x,i)=>{
                let cartage = 0;
                if(x.cartage_available) {
                  cartage = (Boolean(x.product.cartage_override)) ? x.product.cartage : x.product.default_category.cartage;
                } 
                let pickup = (x.pickup) ? 0 : cartage;
                this.cart_data.cart_details[i]['cartage_fee'] = pickup;
                this.cart_data.cart_details[i]['total'] = Number((x.qty*x.product_price*1).toFixed(2));
                total_amount = Number(total_amount)+Number(this.cart_data.cart_details[i]['total']);
            });
            
            this.cart_data.total_amount = Number(this.cart_data.total_amount)+Number(total_amount);
        }
    }
}
</script>